
library(MASS)
library(tidyr)
library(dplyr)

rm(list=ls())


#read in files with clutch size distributions and m and s estimates. These data files contain information on all species
#and, for species from Brommer et al. (2010), multiple populations per species. Later will work only with the populations
#of interest. These are available at https://datadryad.org/stash/dataset/doi:10.5061/dryad.8kprr4xjk

#for convenience, terms here imply that traits are "quality" scores and imply female choice; however, the logic should be robust regardless
#of mechanism


options(dplyr.summarise.inform = FALSE)

BrommerClutchsizeList<-read.table("BrommerEtAlRawDataFile.csv", sep = ",", header = F) #actual data on clutch sizes
colnames(BrommerClutchsizeList)<-c("Population", "NEP", "SizeOfThisClutch")
BrommerClutchsizeList$PopulationF<-as.factor(BrommerClutchsizeList$Population)
Overviews<-read.table("BrommerSpeciesOverViews.csv", sep = ",", header = T) #file containing estimated m and s, and other descriptive info

#step 1 (fig 1)
#create the grid of 20 * 20 territories. Each gets an X coordinate between 1 and 20 and a Y coordinate between 1 and 20
SpatialSim<-as.data.frame(matrix(nrow = 400, ncol = 3))
colnames(SpatialSim)<-c("TerrID", "Xcoord", "Ycoord")
SpatialSim$TerrID<-as.character(row.names(SpatialSim))
SpatialSim$Xcoord<-rep.int(c(1:20), times=20)
SpatialSim$Ycoord<-rep(c(1:20), each=20)

#Determine the distance between all pairs of territories in the population. First determine what the pairs are
#then merge in the location of each territory and finally calculate the distance in terms of territory units
#Terr1 will be the focal territory in down-stream analysis
PairedMatrix<-expand.grid(SpatialSim$TerrID, SpatialSim$TerrID)
colnames(PairedMatrix)<-c("Terr1", "Terr2")
PairedMatrix<-merge(x = PairedMatrix, y = SpatialSim, by.x = "Terr1", by.y = "TerrID", all.x = T)
colnames(PairedMatrix)[3:4]<-c("Terr1X", "Terr1Y")
PairedMatrix<-merge(x = PairedMatrix, y = SpatialSim, by.x = "Terr2", by.y = "TerrID", all.x = T)
colnames(PairedMatrix)[5:6]<-c("Terr2X", "Terr2Y")
PairedMatrix$Distance<-sqrt((PairedMatrix$Terr1X-PairedMatrix$Terr2X)^2+(PairedMatrix$Terr1Y-PairedMatrix$Terr2Y)^2)
PairedMatrix$DistanceWt<-(1/(PairedMatrix$Distance^2))
PairedMatrix$OnDiagonal<-PairedMatrix$Terr2==PairedMatrix$Terr1
PairedMatrix<-subset(PairedMatrix, OnDiagonal=="FALSE") #remove comparisons of the territory to itself
PairedMatrix<-dplyr::select(PairedMatrix, one_of(c("Terr1", "Terr2", "Distance", "DistanceWt"))) #gives the actual distance between
#each pair of territories, as well as the weighted distance to be used in calculating the quotient with male trait score

#set up some empty data frames that will hold the main results at the end. Column names explained as the variables
#are generated later in the code. 
GrandVarianceTerms<-as.data.frame(matrix(nrow=0, ncol =62))
GrandGradientSummary<-as.data.frame(matrix(nrow=0, ncol=17))
GrandPopSummaryTot<-as.data.frame(matrix(nrow=0, ncol=14))
GrandPaired<-as.data.frame(matrix(nrow=0, ncol=16))
GrandEPsireDescrSummary<-as.data.frame(matrix(nrow=0, ncol=15))

#specify some of the conditions for the simulations 
NSims<-100 #number of simulations per population-condition combination. variable n in the for-loops later in code.
PopsOfInterest<-c(6,11,14,18:27,29:30)#list of the empirical populations to be included; 
#This list removes duplicate populations from Brommer et al. 2010. variable x in the for-loops later in code.

#Here, set up for nested for-loops with different simulation conditions
GeoPoss<-"RestrictedG"#c("RestrictedG", "UnrestrictedG") #equivalent to spatially constrained or unconstrained conditions Variable 
#GeographicRestriction in for loops.

NTerritoryRadius<-2.5 #the maximum distance between a focal territory and an extra-pair male where copulation can happen, when 
#spatial constraints are operating. 2.5 used in this paper. This variable has no effect if "UnrestrictedG" is used for GeoPoss

FemPrefFxn<-c(0,1) #the power to which you raise male quality, for creating the association between male quality and
#copulation success. terminology "FemPrefFxn" was used for ease of conceptualization, but the association is not necessarily
#generated by female preference. Variable FPF in for loops.

#additional simulation conditions where the male trait did not affect within-pair success were created manually

FemCrypPrefFxn<-c(0,1) #the power to which you raise sperm quality, for creating the association between sperm quality and
#fertilization success. Variable FCPF in for loops.

WPCrypEff<-c("WPsWeighted", "WPsNotWeighted") #if WPsWeighted, use equation 2 to calculate f, thereby making
#the sperm trait affect within-pair fertilization success. If WPsNotWeighted, use equation 1 to calculate f, so that the 
#sperm trait only affects extra-pair success

DirectionOfCorr2<-c("positive", "negative")  #variable u. specifies whether the male and sperm traits are positively or
#negatively correlated
StrengthOfPrePostCorr<-c(0, 0.1, 0.2, 0.3) #variable DegreeOfCorr. Gives the absolute value of the correlation between male and sperm traits
#note that I typically manually ran correlation = 0 separately, rather than running it both as a "positive" and "negative" correlation
EpisodeInt<-"NotIntegrated"#c("Integrated", "NotIntegrated") #an un-used variable in the paper. For pilot work where fertilization success
#depended on both the male and the sperm trait. 



#create for-loops, with each species experiencing each combination or spatial constraint and male quality-copulation association, sperm quality-fertilization association

for (x in PopsOfInterest){
  for (FPF in FemPrefFxn){
    for(FCPF in FemCrypPrefFxn){
      for(GeographicRestriction in GeoPoss){
        for(u in DirectionOfCorr2){
          
          for (DegreeOfCorr in StrengthOfPrePostCorr){
            for(WPsEff in WPCrypEff){
              for(Integration in EpisodeInt){
                
                UnityMinusDegree <-(1-DegreeOfCorr)
                
                #pull out the clutch size distributions, M, and S, for the population. Also get species ID info.
                PopID<-x
                Thissp<-subset(Overviews, Population==PopID) 
                ClutchsizeListSpecies<-subset(BrommerClutchsizeList, Population==PopID)
                ClutchsizeListSpecies<-subset(ClutchsizeListSpecies, SizeOfThisClutch!=0)
                ClutchsizeList<-as.vector(ClutchsizeListSpecies$SizeOfThisClutch)
                EstM<-Thissp$m
                EstS<-Thissp$s
                Species<-Thissp$species
                
                MQSpermCorrmatrix<-(matrix(DegreeOfCorr, nrow = 2, ncol=2)+diag(2)*UnityMinusDegree) #for creating sperm-malequality correlation
                
                
                #make data frames to hold results of each set of simulations with the same conditions.
                VarianceTerms<-as.data.frame(matrix(nrow=0, ncol =60))
                PopSummaryTot<-as.data.frame(matrix(nrow=0, ncol=11))
                GradientSummary<-as.data.frame(matrix(nrow=0, ncol=15))
                EPsireDescrSummary<-as.data.frame(matrix(nrow=0, ncol=16))
                PairedTot1<-as.data.frame(matrix(nrow=0, ncol=13))
                
                #iterate for the appropriate number of rounds, within one set of conditions.
                for (n in 1:NSims){
                  
                   
                  #create the male and sperm quality scores: first some raw correlated variables, which get manipulated to the quality scores
                  
                  MaleQualList<-as.data.frame(mvrnorm(n = 400, mu = c(0,0), Sigma = MQSpermCorrmatrix))
                  colnames(MaleQualList)<-c("MaleQualpre", "SpQualpre")
                  MaleQualList$TerrID<-as.character(row.names(MaleQualList))
                  
                  MaleQualList$MaleQual<-MaleQualList$MaleQualpre+abs(min(MaleQualList$MaleQualpre))+0.1  #have to make positive, non-zero to use sample function later
                  
                  if (u =="positive") {
                    MaleQualList$SpQual<-MaleQualList$SpQualpre+abs(min(MaleQualList$SpQualpre))+0.1  #have to make positive, non-zero to use sample function later
                  }else{MaleQualList$SpQualpreb<-(-1)*MaleQualList$SpQualpre 
                  MaleQualList$SpQual<-MaleQualList$SpQualpreb+abs(min(MaleQualList$SpQualpreb))+0.1  } #create the negative relationship between male and sperm traits,
                  #if relevant
                  
                  #raise the male and sperm traits to the relevant power
                  MaleQualList$FemPref<-(MaleQualList$MaleQual^FPF)
                  MaleQualList$CrypticFemPref<-MaleQualList$SpQual^FCPF
                  MaleQualList<-dplyr::select(MaleQualList, one_of(c("TerrID", "MaleQual", "FemPref", "SpQual", "CrypticFemPref")))
                  
                  #integrate the scores into the data frame with the distances between territories. First, integrate information for the non-focal
                  #territory
                  PairedMatrix2<-merge(x=PairedMatrix, y=MaleQualList, by.x="Terr2",by.y="TerrID", all.x=T)
                  colnames(PairedMatrix2)<-c("Terr2", "Terr1", "Distance", "DistanceWt", "Male2Qual", "FemPrefMale2", 
                                             "SpQualMale2", "CrypticFemPrefMale2")
                  #then integrate male quality information for the focal territory
                  PairedMatrix2<-merge(x=PairedMatrix2, y=MaleQualList, by.x="Terr1",by.y="TerrID", all.x=T)
                  colnames(PairedMatrix2)<-c("Terr1", "Terr2", "Distance", "DistanceWt", "Male2Qual","FemPrefMale2", "SpQualMale2",
                                             "CrypticFemPrefMale2", "Male1Qual", "FemPrefMale1", "SpQualMale1", "CrypticFemPrefMale1")
                  #we now have a dataframe with one row per pair of territories, with the male and sperm traits, these traits raised to the
                  #appropriate exponent (here called FemPref and CrypticFemPref), for both male 1 (the within-pair male) and male 2 (the potential
                  #extra-pair male)
                  
                  #Next, we need to figure out how many times the male should be cuckolded. Only conditions where the male trait affects both
                  #within-pair and extra-pair success are shown here
                  
                 #when spatial constraints are active and pre-copulatory seleciton is active
                  if (GeographicRestriction=="RestrictedG" & FPF> 0) {
                    ForMDrawing<-PairedMatrix2%>%
                      group_by(Terr1)%>%
                      filter(Distance < NTerritoryRadius)%>% #compare only to neighboring males
                      summarise(MeanOtherMalePref=mean(FemPrefMale2), RelativeMeanMQPref = mean(FemPrefMale2)-mean(FemPrefMale1))%>% #compare the male quality of 
                      #the focal male to those neighboring males
                      ungroup
                    
                    #draw a list of 400 values for m, the number of times the female performs an extra-pair copulation
                    CuckoldryList<-rpois(n=400, lambda=EstM)
                    CuckoldryList<-sort(CuckoldryList, decreasing = T)#sort the values in decreasing order
                    
                    ForMDrawing<-arrange(ForMDrawing, desc(RelativeMeanMQPref)) #sort the males according to their relative quality scores from above
                    ForMDrawing$NTimesCuckolded<-CuckoldryList #merge the number of extra-pair copulations the female does into the data with male
                    #quality and territory ID information
                    ForMDrawing<-dplyr::select(ForMDrawing, one_of(c("Terr1", "NTimesCuckolded"))) #simplify data for merging
                    MaleQualList<-merge(x = MaleQualList, y = ForMDrawing, by.x="TerrID", by.y="Terr1", all.x=T) #merge data back to the original
                    #dataset, only adding information about the number of EP copulations the female performs.
                    
                  } else if (GeographicRestriction=="UnrestrictedG" & FPF> 0){ #for without spatial constraints, but with pre-copulatory selection active
                    MaleQualList<-arrange(MaleQualList, desc(FemPref)) #no need to compare to neighbors; only sort males by quality
                    CuckoldryList<-rpois(n=400, lambda=EstM) #find how many EP copulations females will do
                    CuckoldryList<-sort(CuckoldryList, decreasing = F) #sort
                    MaleQualList$NTimesCuckolded<-CuckoldryList #apply the sorted list of EP copulations to the male quality data set
                  } else {      CuckoldryList<-rpois(n=400, lambda=EstM) #When pre-copulatory selection was not active. This was also the approach
                  #used in the supplementary conditions where male traits affected only extra-pair success; I have not automated it.
                  MaleQualList$NTimesCuckolded<-CuckoldryList
                  }
                  
                  #make data frames to hold results of this population
                  SpatialSim$Clutch<-NA
                  PerEggCopParentageTot<-as.data.frame(matrix(nrow = 0, ncol = 5))
                  colnames(PerEggCopParentageTot)<-c("TerrIDFemale", "SireTerrID", "EggNum", "IsEP", "ClutchSize") #egg number is an ID number per egg; IsEP indicates whether
                  #this egg was fertilized by an EP sire, and ClutchSize is the total number of eggs in the nest
                  ActualCopulationsTot<-as.data.frame(matrix(nrow = 0, ncol = 3))
                  colnames(ActualCopulationsTot)<-c("TerrIDFemale", "EPCopMaleTerrID", "ClutchSize")
                  PotentialEPCopPartners<-as.data.frame(matrix(nrow = 0, ncol = 14))
                  colnames(PotentialEPCopPartners)<-c("Terr1", "Terr2", "Distance", "DistanceWt", "Male2Qual", "FemPrefMale2",
                                                      "SpQualMale2",  "CrypticFemPrefMale2", "Male1Qual", "FemPrefMale1", "SpQualMale1",
                                                      "CrypticFemPrefMale1", "Geographic","ProdOfWts")
                  
                  
                  #for each nest within the population in this simulation, figure out copulations and parentage
                  for (i in 1:400){
                    #get parameters for this nest
                    FocalTerr<-SpatialSim$TerrID[i]
                    SpatialSim$Clutch[i]<-sample(ClutchsizeList, 1, replace = T) #determine the clutch size for the female
                    
                    ThisClutchSize<-SpatialSim$Clutch[i]
                    myM<- MaleQualList$NTimesCuckolded[MaleQualList$TerrID==FocalTerr] #find the number of EP copulations the female 
                    #performs, from the dataset created above
                    
                    #list males that are relevant as possible EP copulation partners, depending on simulation conditions
                    if (GeographicRestriction=="RestrictedG") {  #only neighbors are available; spatial constraints
                      PossibleMales<-PairedMatrix2%>%
                        filter(Terr1 == FocalTerr)%>%
                        filter(Distance < NTerritoryRadius)  #removes males that are too far from being possible copulation partners
                      PossibleMales$Geographic<-PossibleMales$DistanceWt #get the distance weighting for calculating the quotient
                      
                    } else {  PossibleMales<-PairedMatrix2%>%
                      filter(Terr1 == FocalTerr) #all other males are available; no spatial constraints
                    
                    PossibleMales$Geographic<-1    #a dummy variable to faciliate coding--for calculating the quotient of male quality and distance  } 
                    
                    PossibleMales$ProdOfWts<-PossibleMales$Geographic * PossibleMales$FemPrefMale2 #calculating the quotient of distance and male trait.
                    #note that Geographic is 1/1 for conditions without spatial constraints or 1/distance^2 for conditions with spatial constraints
                    
                    
                    PossibleMales2<-sample(PossibleMales$Terr2, myM, replace = T, prob = PossibleMales$ProdOfWts) #perform extra-pair copulations:
                    #females perform extra-pair copulations with the males chose by the sample procedure
                    
                    
                    #get the sperm quality info for the EP copulation partners 
                    CopParts2Qual<-as.data.frame(matrix(nrow=length(PossibleMales2), ncol = 1))
                    colnames(CopParts2Qual)<-"MaleID"
                    CopParts2Qual$MaleID<-PossibleMales2
                    CopParts2Qual<-merge(x =CopParts2Qual, y = MaleQualList, by.x = "MaleID", by.y = "TerrID", all.x=T )
                    
                    #calculate the per-egg probability of being fertilized by EP sperm, using eq 1 or eq 2
                    
                    if (FCPF == 0| WPsEff == "WPsNotWeighted") {ProbEPY<-(myM*EstS)/(myM*EstS+(1-EstS)) #equation 1, post-copulatory selection not active
                    }else if (Integration=="Integrated"){ #not relevant in this manuscript; pilot work where fertilization success also depended on the male trait
                      CopParts2Qual$ProdSQ_MQ<-CopParts2Qual$MaleQual*CopParts2Qual$SpQual
                      MaleQualList$ProdSq_MQ<-MaleQualList$MaleQual*MaleQualList$SpQual
                      SpermQualWPa<- MaleQualList$ProdSq_MQ[MaleQualList$TerrID==FocalTerr] 
                      SpermQualWP<-SpermQualWPa*(1-EstS)
                      EPSpermPower<-sum(CopParts2Qual$ProdSQ_MQ*EstS) 
                      ProbEPY<-EPSpermPower/(EPSpermPower+SpermQualWP)
                    }else  {
                      #equation 2: post copulatory selection active
                      SpermQualWPa<- MaleQualList$SpQual[MaleQualList$TerrID==FocalTerr] 
                      SpermQualWP<-SpermQualWPa*(1-EstS)
                      EPSpermPower<-sum(CopParts2Qual$SpQual*EstS) 
                      ProbEPY<-EPSpermPower/(EPSpermPower+SpermQualWP)  }
                    
                    
                    #create data frames for this nest's results
                    PerEggCopParentage<-as.data.frame(matrix(nrow = ThisClutchSize, ncol = 5))
                    colnames(PerEggCopParentage)<-c("TerrIDFemale", "SireTerrID", "EggNum", "IsEP", "ClutchSize")
                    PerEggCopParentage$ClutchSize<-ThisClutchSize
                    ActualCopulations<-as.data.frame(matrix(nrow = length(PossibleMales2), ncol = 3))
                    colnames(ActualCopulations)<-c("TerrIDFemale", "EPCopMaleTerrID", "ClutchSize")
                    
                    #for each egg, figure out if it is EP or WP sired. if EP, figure out the sire.
                    for (j in 1:ThisClutchSize) {
                      PerEggCopParentage$EggNum[j]<-j
                      PerEggCopParentage$TerrIDFemale[j]<-FocalTerr
                      PerEggCopParentage$IsEP[j]<-rbinom(n = 1, size = 1, prob = ProbEPY) #1 if EP, 0 if WP
                      
                      #identifying sires: need different code if the female did EP copulations or didn't.
                      #if she did:
                      if (length(PossibleMales2)>0){ if (Integration =="Integrated") { #this not relevant for this paper
                        CopParts2Qual$FemPrefProd<-CopParts2Qual$FemPref*CopParts2Qual$CrypticFemPref
                        PerEggCopParentage$SireTerrID[j]<-ifelse(PerEggCopParentage$IsEP[j]==1, 
                                                                 sample(CopParts2Qual$MaleID, 1, replace = T, prob = CopParts2Qual$FemPrefProd),
                                                                 FocalTerr)
                      }else{
                        PerEggCopParentage$SireTerrID[j]<-ifelse(PerEggCopParentage$IsEP[j]==1, 
                                                                 sample(CopParts2Qual$MaleID, 1, replace = T, prob = CopParts2Qual$CrypticFemPref),
                                                                 FocalTerr)}}else{
                                                                   PerEggCopParentage$SireTerrID[j]<-FocalTerr #if the female did no extra-pair copulations,
                                                                   #all eggs are sired by the within-pair male
                                                                 }
                    }
                    
                    
                    #put the results from this nest in with the rest of the population
                    PerEggCopParentageTot<-rbind(PerEggCopParentageTot,PerEggCopParentage )
                    PotentialEPCopPartners<-rbind(PotentialEPCopPartners, PossibleMales)
                    
                    # #if the female copulated with any EP males, make a list of who she copulated with, for later analysis--not actually used in this paper
                    if (length(PossibleMales2)>0) {
                      ActualCopulations$ClutchSize<-ThisClutchSize
                      for (k in 1:length(PossibleMales2)) {
                        ActualCopulations$TerrIDFemale[k]<-FocalTerr
                        ActualCopulations$EPCopMaleTerrID[k]<-PossibleMales2[k]
                      } }
                    #add that list to the population-wide summary
                    ActualCopulationsTot<-rbind(ActualCopulationsTot, ActualCopulations)
                    
                  }
                  
                  #PerEggCopParentageTot contains parentage information on all the kid, EP and WP. ActualCopulationsTot contains a list
                  #of ONLY EP copulations. 
                  
                  #now, find population-wide measures. Many of these are only used in the supplementary information for how many copulations
                  #and sires there were per nest, etc. Also there are several hold-overs from analyses done in  other manuscripts, and potentially
                    #interesting background information.
                  
                  #find reproductive success (RSFem) of the female as well as number of EP offspring she had (NEPKidsFem), 
                    #and the number of copulation partners with shared kids (NGeneticMatesforFem). 
                  FemaleSummary<-PerEggCopParentageTot%>%
                    group_by(TerrIDFemale)%>%
                    summarise(NGeneticMatesforFem = length(unique(SireTerrID)), RSFem = length(EggNum), NEPKidsFem = sum(IsEP))%>%
                    ungroup()
                  
                  #find female copulatory success (ie, true number of mates, not detected)
                  FemaleCopSummary<-ActualCopulationsTot%>%
                    group_by(TerrIDFemale)%>%
                    summarise(NEPCopPartForFem=length(unique(EPCopMaleTerrID)))%>%
                    ungroup()
                  
                  
                  #find out EP success, detected number of mates (ie, number copulation partners with shared kids, NEPMatesDetforMale, almost equivalent to NGeneticMatesforFem), for the male. 
                  MaleEPPSummaryC<-PerEggCopParentageTot%>%
                    filter(SireTerrID!=TerrIDFemale)%>%
                    group_by(SireTerrID)%>%
                    summarise(NEPMatesDetforMale = length(unique(TerrIDFemale)),  NEPKidsMale=sum(IsEP))%>%
                    ungroup()
                  
                  #find out number of EP copulation partners for males
                  MaleCopSummary<-ActualCopulationsTot%>%
                    group_by(EPCopMaleTerrID)%>%
                    summarise(NEPCopPartForMale=length(unique(TerrIDFemale)))%>%
                    ungroup()
                  
                  #Create a dataframe containing all the information, as well as the spatial lay-out, for analysis by merging
                  #the summaries of the simulation into the Spatialsim dataframe. 
                  SpatialSimForAnalysis<-merge(x = SpatialSim, y = FemaleSummary, by.x = "TerrID", by.y = "TerrIDFemale", all.x = T)
                  SpatialSimForAnalysis<-merge(x = SpatialSimForAnalysis, y = FemaleCopSummary, by.x = "TerrID", by.y = "TerrIDFemale", all.x = T)
                  
                  SpatialSimForAnalysis<-merge(x = SpatialSimForAnalysis, y = MaleEPPSummaryC, by.x = "TerrID", by.y = "SireTerrID", all.x = T)
                  SpatialSimForAnalysis<-merge(x = SpatialSimForAnalysis, y = MaleCopSummary, by.x = "TerrID", by.y = "EPCopMaleTerrID", all.x = T)
                  SpatialSimForAnalysis<-merge(x = SpatialSimForAnalysis, y = MaleQualList, by = "TerrID",  all.x=T)
                  
                  #fill in 0's for NAs where appropriate. Some of these will never be NA for this manuscript, but the code is hold-over from other
                  #papers
                  SpatialSimForAnalysis$RSFem<-ifelse(is.na(SpatialSimForAnalysis$RSFem)==T, 0,
                                                      SpatialSimForAnalysis$RSFem) 
                  SpatialSimForAnalysis$NEPKidsFem<-ifelse(is.na(SpatialSimForAnalysis$NEPKidsFem)==T, 0,
                                                           SpatialSimForAnalysis$NEPKidsFem)  
                  SpatialSimForAnalysis$NEPCopPartForFem<-ifelse(is.na(SpatialSimForAnalysis$NEPCopPartForFem)==T, 0,
                                                                 SpatialSimForAnalysis$NEPCopPartForFem)
                  SpatialSimForAnalysis$NEPCopPartForMale<-ifelse(is.na(SpatialSimForAnalysis$NEPCopPartForMale)==T, 0,
                                                                  SpatialSimForAnalysis$NEPCopPartForMale)
                  SpatialSimForAnalysis$NEPMatesDetforMale<-ifelse(is.na(SpatialSimForAnalysis$NEPMatesDetforMale)==T, 0,
                                                                   SpatialSimForAnalysis$NEPMatesDetforMale)
                  
                  #figure out male's WP success. All males have equal WP copulation success in our simulation, so there should be no NA's only true
                  #0's for proportion sired.
                  #this dataframe is the source for most of the analytical approaches used. it has one row per male-female social pair
                  SpatialSimForAnalysis$NWPKids<-SpatialSimForAnalysis$RSFem-SpatialSimForAnalysis$NEPKidsFem
                  
                  SpatialSimForAnalysis$NEPKidsMale<-ifelse(is.na(SpatialSimForAnalysis$NEPKidsMale)==T, 0,
                                                            SpatialSimForAnalysis$NEPKidsMale) #necessary for the ep vs wp partitioning
                  
                  SpatialSimForAnalysis$RSMale<-SpatialSimForAnalysis$NEPKidsMale+SpatialSimForAnalysis$NWPKids
                  
                  
                  #for differential of siring kids vs not, and for sorting out t-tests: create categorical variables about whether or not the male sired within-pair offspring,
                  #whether or not any offspring in his social nest were sired by other males, whether or not he sired any offspring in other males' nests
                  SpatialSimForAnalysis$SiredWPkids<-0
                  SpatialSimForAnalysis$SiredWPkids[SpatialSimForAnalysis$NWPKids>0]<-1
                  SpatialSimForAnalysis$Cuckolded<-0
                  SpatialSimForAnalysis$Cuckolded<-ifelse(SpatialSimForAnalysis$NEPKidsFem>0, 1,SpatialSimForAnalysis$Cuckolded)
                  SpatialSimForAnalysis$SiredEPY<-0
                  SpatialSimForAnalysis$SiredEPY<-ifelse(SpatialSimForAnalysis$NEPKidsMale>0, 1,SpatialSimForAnalysis$SiredEPY)
                  
                  #calculate the proportion of offspring in his social nest sired by extra-pair sires, and the proportion sired by the social male
                  SpatialSimForAnalysis$ProportionKidsLostToEPY<-SpatialSimForAnalysis$NEPKidsFem/SpatialSimForAnalysis$RSFem
                  SpatialSimForAnalysis$ProportionWPKidsKeptAfterEPC<-SpatialSimForAnalysis$NWPKids/SpatialSimForAnalysis$RSFem
                  
                  #for looking at the proportion of extra-pair brood(s) sired by particular extra-pair males, we need a different data frame with
                  #one row per extra-pair male-female pair. This is also used in variance partitioning
                  
                  #get a list of all the extra-pair copulations that resulted in offspring
                  EPPHappened<-PerEggCopParentageTot%>%
                    filter(IsEP==1)%>%
                    mutate(GeneticDad_Mom=paste(SireTerrID, TerrIDFemale, sep="_"))%>%
                    group_by(SireTerrID, TerrIDFemale, GeneticDad_Mom, IsEP)%>%
                    summarise(NEPYtog=sum(IsEP))%>%
                    ungroup()%>%
                    dplyr::select(-SireTerrID, -TerrIDFemale)
                  
                  
                  #find out how many extra-pair copulations a male and female performed together, as well as getting female clutch
                  #size for variance partitioning
                  EPCopSummaryTot<-ActualCopulationsTot%>%
                    group_by(TerrIDFemale, EPCopMaleTerrID)%>%
                    summarise(NEPcopsTog=length(ClutchSize), FemClutchSize=mean(ClutchSize))%>%
                    ungroup()%>%
                    mutate(EPmalecop_Fem=paste(EPCopMaleTerrID, TerrIDFemale, sep="_"))
                  
                  EPCopSummaryTot<-merge(x = EPCopSummaryTot, y = EPPHappened, by.x="EPmalecop_Fem", by.y="GeneticDad_Mom", all.x=T) 
                  
                  #fill in 0's where needed
                  EPCopSummaryTot$IsEP<-ifelse(is.na(EPCopSummaryTot$IsEP)==T, 0,
                                               EPCopSummaryTot$IsEP)
                  EPCopSummaryTot$NEPYtog<-ifelse(is.na(EPCopSummaryTot$NEPYtog)==T, 0,
                                                  EPCopSummaryTot$NEPYtog)
                  
                  #get additional information on the sperm trait and the number of EPY the female had total, and merge this into the above data frame
                  MQualSimple<-MaleQualList%>%
                    dplyr::select(one_of(c("TerrID", "SpQual")))
                  
                  FemEPYSimple<-SpatialSimForAnalysis%>%
                    dplyr::select(one_of(c("TerrID", "NEPKidsFem")))
                  
                  EPCopSummaryTot<-merge(x = EPCopSummaryTot, y = MQualSimple, by.x="EPCopMaleTerrID", by.y="TerrID", all.x=T)
                  EPCopSummaryTot<-merge(x = EPCopSummaryTot, y = FemEPYSimple, by.x="TerrIDFemale", by.y="TerrID", all.x=T)
                  
                 
                  #Remove the territories that are 3 units or closer to the edge of the study plot
                  SpatialSimForAnalysis<-subset(SpatialSimForAnalysis, Xcoord > 3 & Xcoord < 17)
                  SpatialSimForAnalysis<-subset(SpatialSimForAnalysis, Ycoord > 3 & Ycoord < 17)
                  
                  CentralTerritories<-SpatialSimForAnalysis$TerrID #create a list of the territory ID's that are in the core (included) part of the 
                  #study site for later checking
                  
                  #standardizing reproductive success for selection gradients
                  MeanmaleRS<-mean(SpatialSimForAnalysis$RSMale)
                  SpatialSimForAnalysis$RSMaleStd<-SpatialSimForAnalysis$RSMale/MeanmaleRS 
                 
                  
                  #standardizing male, sperm traits as predictor variables
                  MeanSQ<-mean(SpatialSimForAnalysis$SpQual)
                  SD_SQ<-sd(SpatialSimForAnalysis$SpQual)
                  SpatialSimForAnalysis$SpQualStd<-(SpatialSimForAnalysis$SpQual-MeanSQ)/SD_SQ
                  
                  MeanMQ<-mean(SpatialSimForAnalysis$MaleQual)
                  SD_MQ<-sd(SpatialSimForAnalysis$MaleQual)
                  SpatialSimForAnalysis$MaleQualStd<-(SpatialSimForAnalysis$MaleQual-MeanMQ)/SD_MQ
                  
                  #step 1 of variance partitioning, plus some descriptive information. Will end up with one row for this whole population
                  VarTermsDet<-SpatialSimForAnalysis%>%
                    mutate(NEPSiresInBrood = NGeneticMatesforFem-SiredWPkids, NUnsuccessfulEPCopPart=NEPCopPartForFem-NEPSiresInBrood,
                           NestPropEPY=(NEPKidsFem/Clutch), PropUnsuccessfulEPCopPart=NUnsuccessfulEPCopPart/NEPCopPartForFem)%>%
                    summarise(PropEPY = mean(NestPropEPY), MeanNEPYperNest = mean(NEPKidsFem), MeanNEPSiresPerBrood=mean(NEPSiresInBrood),
                              MeanUnsuccessfulEPCopPartFem=mean(NUnsuccessfulEPCopPart), SDNEPSiresPerBrood=sd(NEPSiresInBrood),
                              SDUnsuccessfulEPCopPartFem=sd(NUnsuccessfulEPCopPart), VarMaleRSUnStd=var(RSMale), MeanMaleRSUnStd=mean(RSMale),
                              MeanPropUnsuccessfulEPCopPart=mean(PropUnsuccessfulEPCopPart))
                  #PropEPY: mean proportion of chicks in each brood that are EP. MeanNEPYperNest: mean number of EPY in each nest. MeanNEPSiresPerBrood: Mean number
                  #of extrapair sires in each nest. MeanUnsuccessfulEPCopPartFem: mean number of EP copulation partners that did not sire any extra-pair offspring with that
                  #female (ie, undetected copulations). Two variables showing standard deviation of these. Unstandardized variance and mean male reproductive success 
                  #(VarMaleRSUnStd, MeanMaleRSUnStd). Per-female mean proportion of extrapair copulation partners that did not sire any EPY
                  
                  
                  # 
                  # #add more information that is a useful summary of the population parameters for this population
                  NBroodsEP<-length(SpatialSimForAnalysis$TerrID[SpatialSimForAnalysis$NEPKidsFem>0]) #number of broods with at least 1 EPY
                  NBroods<-length(SpatialSimForAnalysis$TerrID) #number of broods total
                  VarTermsDet$PropEPBroods<-NBroodsEP/NBroods
                  
                  #creating a different dataset looking at the copulations that occurred
                  
                  EPCopSummaryTotSum<-EPCopSummaryTot%>%
                    filter(TerrIDFemale %in% CentralTerritories)
                  
                  EPCopSummaryTotSum2<-EPCopSummaryTot%>%
                    filter(TerrIDFemale %in% CentralTerritories)%>%
                    group_by(TerrIDFemale)%>%
                    top_n(n=1, wt = NEPYtog)%>%
                    ungroup() 
                  
                  VarTermsDet$ObservedMaleSpQualCorr<-cor(SpatialSimForAnalysis$MaleQual, SpatialSimForAnalysis$SpQual)
                  
                  
                  #doing analyses: for each, run the analysis, save results in a data frame, and label the dataframe with the type of analysis and the predictors.
                  #in the end, one data frame for regression-based results and one for t-tests.
                  #Univariate selection gradients
                  MaleEffBeta<-as.data.frame(summary(lm(RSMaleStd~MaleQualStd, data = SpatialSimForAnalysis))$coefficients)
                  MaleEffBeta$Model<-"MaleQualRSSimple"
                  MaleEffBeta$Predictor<-row.names(MaleEffBeta)
                  
                  SpermEffBeta<-as.data.frame(summary(lm(RSMaleStd~SpQualStd, data = SpatialSimForAnalysis))$coefficients)
                  SpermEffBeta$Model<-"SpQualRSSimple"
                  SpermEffBeta$Predictor<-row.names(SpermEffBeta)
                  
                  #multivariate selection gradient
                  SpermMaleEffBeta<-as.data.frame(summary(lm(RSMaleStd~SpQualStd+MaleQualStd, data = SpatialSimForAnalysis))$coefficients)
                  SpermMaleEffBeta$Model<-"BothvsRS"
                  SpermMaleEffBeta$Predictor<-row.names(SpermMaleEffBeta)
                  
                  #begin gathering results from regression-based analytical approaches
                  GradientSumm<-rbind(MaleEffBeta,  SpermEffBeta, SpermMaleEffBeta)
                  
                  #check to be sure there were at least 3 males cuckolded
                  if(sum(SpatialSimForAnalysis$Cuckolded)>2) {
                    
                    #if so, find out if WP sperm quality affects the proportion of WP kids sired, considering only nests where we know from field data
                    #than an EP copulation happened
                    SpermMaleKeptWPP<-as.data.frame(summary(lm(ProportionWPKidsKeptAfterEPC~SpQualStd, data = SpatialSimForAnalysis, subset = Cuckolded == 1))$coefficients)
                    SpermMaleKeptWPP$Model<-"PropWPYKept"
                    SpermMaleKeptWPP$Predictor<-row.names(SpermMaleKeptWPP)
                    GradientSumm<-rbind(GradientSumm, SpermMaleKeptWPP) #add it to the overall regression results
                  }
                  
                  
                  #finish making the data frame for looking at other perspectives
                  #Get a list of all the copulation partners that were available
                  PotentialEPCopPartners$GeneticDad_Mom<-paste(PotentialEPCopPartners$Terr2, PotentialEPCopPartners$Terr1, sep="_")
                  PotentialEPCopPartners2<-merge(x = PotentialEPCopPartners, y = EPPHappened, by = "GeneticDad_Mom", all.x=T)
                  PotentialEPCopPartners2$IsEP<-ifelse(is.na(PotentialEPCopPartners2$IsEP)==T, 0,
                                                       PotentialEPCopPartners2$IsEP)
                  
                  #for looking at ep siring success, remove edge territories
                  EPCopSummaryTot<-EPCopSummaryTot%>%
                    filter(EPCopMaleTerrID %in% CentralTerritories)
                  
                  VarTermsDet$MeanNEPCsTog<-mean(EPCopSummaryTot$NEPcopsTog) #average number of extra-pair copulations per male-female combo
                  VarTermsDet$SDNEPCsTog<-sd(EPCopSummaryTot$NEPcopsTog) #sd of that varialbe
                  
                  if(sum(SpatialSimForAnalysis$SiredEPY)>2) { #only do this if at least 3 males in the core area sired extra-pair young
                    
                    #regression of sperm quality on number of detected mates
                    SpermEffMatingBeta<-as.data.frame(summary(lm(SpQual~NEPMatesDetforMale, data = SpatialSimForAnalysis))$coefficients)
                    SpermEffMatingBeta$Model<-"SpQualDetMates"
                    SpermEffMatingBeta$Predictor<-row.names(SpermEffMatingBeta)
                    
                    #standardize the sperm trait within this population of males, calculate the proportion of the brood sired by individual EP males
                    MeanSQB<-mean(EPCopSummaryTot$SpQual[EPCopSummaryTot$IsEP==1])
                    SD_SQB<-sd(EPCopSummaryTot$SpQual[EPCopSummaryTot$IsEP==1])
                    EPCopSummaryTot$SpQualStd<-(EPCopSummaryTot$SpQual-MeanSQB)/SD_SQB
                    EPCopSummaryTot$PropKidsSiredThisEPY<-log(EPCopSummaryTot$NEPYtog/EPCopSummaryTot$FemClutchSize)
                    
                    #regress proportion of extra-pair brood sired on extra-pair sperm, adding a random effect if any male sired
                    #extra-pair young in more than one nest
                    if(length(unique(EPCopSummaryTot$EPCopMaleTerrID[EPCopSummaryTot$IsEP==1]))>sum(EPCopSummaryTot$IsEP)){
                      
                      PropEPYSiredBinomDetcops<-as.data.frame(summary(lmer(PropKidsSiredThisEPY~SpQualStd +(1|EPCopMaleTerrID), 
                                                                           data = EPCopSummaryTot, subset = IsEP==1))$coefficients)
                      PropEPYSiredBinomDetcops$Model<-"SpQualEPKidsGainedFieldKnowledge"
                      PropEPYSiredBinomDetcops$Predictor<-row.names(PropEPYSiredBinomDetcops)
                      PropEPYSiredBinomDetcops<-PropEPYSiredBinomDetcops%>%
                        dplyr::select(-df) #remove a column that is different for lmer and lm models
                      colnames(PropEPYSiredBinomDetcops)<-colnames(SpermEffBeta)}else{
                        
                        PropEPYSiredBinomDetcops<-as.data.frame(summary(lm(PropKidsSiredThisEPY~SpQualStd , 
                                                                           data = EPCopSummaryTot, subset = IsEP==1))$coefficients)
                        PropEPYSiredBinomDetcops$Model<-"SpQualEPKidsGainedFieldKnowledge"
                        PropEPYSiredBinomDetcops$Predictor<-row.names(PropEPYSiredBinomDetcops)
                        colnames(PropEPYSiredBinomDetcops)<-colnames(SpermEffBeta)
                      }
                    
                    #finish gathering regression-based results
                    GradientSumm<-rbind(GradientSumm,SpermEffMatingBeta, PropEPYSiredBinomDetcops)
                    
                    #prep for and do some t tests
                    SuccEPCops<-PotentialEPCopPartners2%>%
                      filter(IsEP==1)%>% #getting only the copulations that produced offspring
                      filter(Terr2 %in% CentralTerritories)%>% #pulling out only males in the core territories. Terr 2 is the EP male's territory ID
                      dplyr::select(one_of(c("Terr1", "Terr2", "Male2Qual", "SpQualMale2", "Male1Qual", "SpQualMale1" )))
                    colnames(SuccEPCops)<-c("FemID", "EPGeneticSireID", "EPsireMaleQual", "EPsireSpQual", "WPsireMaleQual", "WPsireSpQual")
                    
                    #paired tests of the extra-pair males and the within-pair males they cuckolded  
                    PairedMQ<-t.test(SuccEPCops$EPsireMaleQual, SuccEPCops$WPsireMaleQual,  paired=T)
                    paireResults<-as.data.frame(cbind(PairedMQ$statistic, PairedMQ$parameter, PairedMQ$estimate, PairedMQ$'p.value'))
                    paireResults$TestType<-"EPvsWPMale"
                    
                    PairedSQ<-t.test(SuccEPCops$EPsireSpQual, SuccEPCops$WPsireSpQual, paired=T)
                    paireSResults<-as.data.frame(cbind(PairedSQ$statistic, PairedSQ$parameter, PairedSQ$estimate, PairedSQ$'p.value'))
                    paireSResults$TestType<-"EPvsWPSperm"
                    
                    #unpaired t-test of males that did or did not sire extra-pair young in other nests, flipping the direction of the
                    #test statistic to make a positive expectation 
                    UnpairedEPSireT<-t.test(SpatialSimForAnalysis$SpQual~SpatialSimForAnalysis$SiredEPY)
                    SiredEPUnpairedRes<-as.data.frame(cbind(UnpairedEPSireT$statistic*(-1), UnpairedEPSireT$parameter,
                                                            UnpairedEPSireT$estimate[2]-UnpairedEPSireT$estimate[1], 
                                                            UnpairedEPSireT$'p.value')) #flips orientation to give yes EP sire - not EP sire
                    SiredEPUnpairedRes$TestType<-"SiredEPVsNotSQ"
                    
                    
                    UnpairedEPSireTMQ<-t.test(SpatialSimForAnalysis$MaleQual~SpatialSimForAnalysis$SiredEPY)
                    SiredEPUnpairedResMQ<-as.data.frame(cbind(UnpairedEPSireTMQ$statistic*(-1), UnpairedEPSireTMQ$parameter,
                                                              UnpairedEPSireTMQ$estimate[2]-UnpairedEPSireTMQ$estimate[1], 
                                                              UnpairedEPSireTMQ$'p.value')) #flips orientation to give yes EP sire - not EP sire
                    SiredEPUnpairedResMQ$TestType<-"SiredEPVsNotMQ"
                    
                    
                    pairedTot<-rbind(paireResults, paireSResults,  SiredEPUnpairedRes, SiredEPUnpairedResMQ) #create a dataframe to hold t-test results
                  }else{
                    pairedTot<-as.data.frame(matrix(nrow=0, ncol = 6)) #create a dataframe to hold t-test results in case there were too few males to do the above tests
                  }
                  
                  if(sum(SpatialSimForAnalysis$Cuckolded)>2) { #continuing t-tests, for the males that were or were not cuckolded, if there are enough
                    
                    UnpairedCuckoldedT<-t.test(SpatialSimForAnalysis$SpQual~SpatialSimForAnalysis$Cuckolded)
                    cuckoldedUnpairedRes<-as.data.frame(cbind(UnpairedCuckoldedT$statistic, UnpairedCuckoldedT$parameter,
                                                              UnpairedCuckoldedT$estimate[1]-UnpairedCuckoldedT$estimate[2], 
                                                              UnpairedCuckoldedT$'p.value'))#mean in uncuckolded - mean in cuckolded
                    cuckoldedUnpairedRes$TestType<-"CuckoldedVsNotSQ"
                    pairedTot<-rbind(pairedTot, cuckoldedUnpairedRes)
                    
                    UnpairedCuckoldedTMQ<-t.test(SpatialSimForAnalysis$MaleQual~SpatialSimForAnalysis$Cuckolded)
                    cuckoldedUnpairedResMQ<-as.data.frame(cbind(UnpairedCuckoldedTMQ$statistic, UnpairedCuckoldedTMQ$parameter,
                                                                UnpairedCuckoldedTMQ$estimate[1]-UnpairedCuckoldedTMQ$estimate[2], 
                                                                UnpairedCuckoldedTMQ$'p.value'))#mean in uncuckolded - mean in cuckolded
                    cuckoldedUnpairedResMQ$TestType<-"CuckoldedVsNotMQ"
                    pairedTot<-rbind(pairedTot, cuckoldedUnpairedResMQ) #put these into the t-test result data frame
                    
                  }
                  
                  
                  if(nrow(pairedTot)==0) {pairedTot<-as.data.frame(matrix(nrow=0, ncol = 14))}else{#in case no t-tests are done
                    
                    #"label" the t-test results with simulation conditions
                    colnames(pairedTot)<-c("Tstatistic", "dfTtest", "PairedDiff", "Pval", "TestType")
                    pairedTot$SimID<-n
                    pairedTot$Geography<-GeographicRestriction
                    pairedTot$ConstraintDist<-NTerritoryRadius
                    pairedTot$FemPower<-FPF
                    pairedTot$FemCrypticPower<-FCPF
                    pairedTot$DirectionSpMaleQualCorr<-u
                    pairedTot$StrengthSpMaleQualCorr<-DegreeOfCorr
                    pairedTot$WPsWeighting<-WPsEff
                    pairedTot$EpisodeRelation<-Integration
                  }
                  
                  #put the paired t-test results from this population in with the results from the same simulation conditions
                  PairedTot1<-rbind(PairedTot1, pairedTot)
                  
                  #"label" the regression results with simulation conditions
                  GradientSumm$SimID<-n
                  GradientSumm$Geography<-GeographicRestriction
                  GradientSumm$ConstraintDist<-NTerritoryRadius
                  GradientSumm$FemPower<-FPF
                  GradientSumm$FemCrypticPower<-FCPF
                  GradientSumm$DirectionSpMaleQualCorr<-u
                  GradientSumm$StrengthSpMaleQualCorr<-DegreeOfCorr
                  GradientSumm$WPsWeighting<-WPsEff
                  GradientSumm$EpisodeRelation<-Integration
                  #combining this population with the results from other populations under the same conditions
                  GradientSummary<-rbind(GradientSummary, GradientSumm)
                  
                  #Prepare more for variance partitioning. Naming of variables should be fairly self-explanatory, with _WP indicating withinpair and _EP indicating extra-pair.
                  #see table S1
                  EPCopSummaryTot3<-EPCopSummaryTot%>%
                    dplyr::select(one_of(c("EPCopMaleTerrID", "NEPYtog", "FemClutchSize")))
                  colnames(EPCopSummaryTot3)<-c("MaleID", "NEggsFertilized", "FemFecundity")
                  
                  EPCopSummaryTot3<-EPCopSummaryTot3%>%
                    group_by(MaleID)%>%
                    summarise(MatingSucc_EP=length(NEggsFertilized), NEggsFert_EP=sum(NEggsFertilized), 
                              TotFemFec=sum(FemFecundity), AvePartnerFec_EP=mean(FemFecundity))%>%
                    mutate(FertSucc_EP=NEggsFert_EP/TotFemFec)%>%
                    dplyr::select(-"TotFemFec")%>%
                    ungroup()
                  #this gives a row for each male that performed extra-pair copulations, though he may not have fertilized any eggs
                  
                  SpatialSimForAnalysis2<-SpatialSimForAnalysis%>%
                    dplyr::select(one_of(c("TerrID", "NWPKids", "Clutch")))
                  colnames(SpatialSimForAnalysis2)<-c("MaleID", "NEggsFertilized", "FemFecundity")
                  
                  MoreVar2<-merge(SpatialSimForAnalysis2, EPCopSummaryTot3,  by = "MaleID", all.x=T) #this will give a row for each male with a territory
                  #in the core of the study plot
                  colnames(MoreVar2)[2]<-"NEggsFert_WP"
                  colnames(MoreVar2)[3]<-"AvePartnerFec_WP"
                  
                  #fill in 0 values for males that did not perform extra-pair copulations
                  MoreVar2$MatingSucc_EP<-ifelse(is.na(MoreVar2$MatingSucc_EP)==T, 0,
                                                 MoreVar2$MatingSucc_EP) 
                  MoreVar2$NEggsFert_EP<-ifelse(is.na(MoreVar2$NEggsFert_EP)==T, 0,
                                                MoreVar2$NEggsFert_EP) 
                  MoreVar2$AvePartnerFec_EP<-ifelse(is.na(MoreVar2$AvePartnerFec_EP)==T, 0,
                                                    MoreVar2$AvePartnerFec_EP) 
                  MoreVar2$FertSucc_EP<-ifelse(is.na(MoreVar2$FertSucc_EP)==T, 0,
                                               MoreVar2$FertSucc_EP) 
                  MoreVar2$MatingSucc_WP<-1 #all males are assumed to copulate with their wp female
                  MoreVar2$FertSucc_WP<-MoreVar2$NEggsFert_WP/MoreVar2$AvePartnerFec_WP
                  MoreVar2$RS<-MoreVar2$NEggsFert_EP+MoreVar2$NEggsFert_WP
                  
                  #calculate variance components for the components where all males should be included
                  MoreVar2B<-MoreVar2%>%
                    summarise(MeanRS=mean(RS), VarRS=var(RS),
                              MeanMS_WP=mean(MatingSucc_WP), VarMS_WP=var(MatingSucc_WP), 
                              MeanMS_EP=mean(MatingSucc_EP), VarMS_EP=var(MatingSucc_EP), 
                              MeanFec_WPfem=mean(AvePartnerFec_WP), VarFec_WPfem=var(AvePartnerFec_WP),
                              MeanFertSucc_WP=mean(FertSucc_WP), VarFertSucc_WP=var(FertSucc_WP),
                              Cov2MMS_MFS_WP=2*cov(MatingSucc_WP,FertSucc_WP),
                              Cov2MMS_Fec_WP=2*cov(MatingSucc_WP,AvePartnerFec_WP), 
                              Cov2Fec_MFS_WP=2*cov(AvePartnerFec_WP,FertSucc_WP),
                              Cov2_WPMMS_EPMMS=2*cov(MatingSucc_WP, MatingSucc_EP),
                              Cov2_WPFec_EPMMS=2*cov(AvePartnerFec_WP, MatingSucc_EP), 
                              Cov2_WPMFS_EPMMS=2*cov(FertSucc_WP, MatingSucc_EP))
                  
                  #remove the males that had 0 EP copulation success before calculating variance components dealing with EP mate fecundity and EP fertilization
                  #success, as recommended in the literature (see supplementary text)
                  MoreVar2C<-MoreVar2%>%
                    filter(MatingSucc_EP>0)%>%
                    summarise(MeanFec_EPfem=mean(AvePartnerFec_EP), VarFec_EPfem=var(AvePartnerFec_EP),
                              MeanFertSucc_EP=mean(FertSucc_EP), VarFertSucc_EP=var(FertSucc_EP),
                              Cov2MMS_MFS_EP=2*cov(MatingSucc_EP,FertSucc_EP),
                              Cov2MMS_Fec_EP=2*cov(MatingSucc_EP,AvePartnerFec_EP),
                              Cov2Fec_MFS_EP=2*cov(AvePartnerFec_EP,FertSucc_EP),
                              Cov2_WPMMS_EPFec=2*cov(MatingSucc_WP, AvePartnerFec_EP),
                              Cov2_WPMMS_EPMFS=2*cov(MatingSucc_WP, FertSucc_EP), 
                              Cov2_WPFec_EPMFec=2*cov(AvePartnerFec_WP, AvePartnerFec_EP), Cov2_WPFec_EPMFS=2*cov(AvePartnerFec_WP, FertSucc_EP), 
                              Cov2_WPMFS_EPFec=2*cov(FertSucc_WP, AvePartnerFec_WP),
                              Cov2_WPMFS_EPMFS=2*cov(FertSucc_WP, FertSucc_EP))
                
                  
                  VarTermsDet<-cbind(VarTermsDet, MoreVar2B, MoreVar2C) #merge this all together
                  
                  #label variance partitioning and descriptive data
                  VarTermsDet$SimID<-n
                  VarTermsDet$Geography<-GeographicRestriction
                  VarTermsDet$ConstraintDist<-NTerritoryRadius
                  VarTermsDet$FemPower<-FPF
                  VarTermsDet$FemCrypticPower<-FCPF
                  VarTermsDet$DirectionSpMaleQualCorr<-u
                  VarTermsDet$StrengthSpMaleQualCorr<-DegreeOfCorr
                  VarTermsDet$WPsWeighting<-WPsEff
                  VarTermsDet$EpisodeRelation<-Integration
                  
                  
                  # #add the results from this population to other populations with same simulation conditions
                  VarianceTerms<-rbind(VarianceTerms, VarTermsDet)
                  
                  #label some additiona descriptive data
                  EPPHappened$SimID<-n
                  EPPHappened$Geography<-GeographicRestriction
                  EPPHappened$ConstraintDist<-NTerritoryRadius
                  EPPHappened$FemPower<-FPF
                  EPPHappened$FemCrypticPower<-FCPF
                  EPPHappened$DirectionSpMaleQualCorr<-u
                  EPPHappened$StrengthSpMaleQualCorr<-DegreeOfCorr
                  EPPHappened$WPsWeighting<-WPsEff
                  EPPHappened$EpisodeRelation<-Integration
                  
                  
                  
                  EPsireDescrSummary<-rbind(EPsireDescrSummary, EPPHappened)
                  # 
                  # 
                   # 
                  #if we want to look at the distribution of paternity across nests, here's where we gather that info for this population and add it
                  #to other populations with the same simulation conditions
                  PopSummary<-SpatialSimForAnalysis%>%
                    group_by(Clutch, NEPKidsFem)%>%
                    summarise(NBroodsWithXEPKids=length(Clutch))%>%
                    ungroup()
                  PopSummary$SimID<-n
                  PopSummary$Geography<-GeographicRestriction
                  PopSummary$ConstraintDist<-NTerritoryRadius
                  PopSummary$FemPower<-FPF
                  PopSummary$FemCrypticPower<-FCPF
                  PopSummary$DirectionSpMaleQualCorr<-u
                  PopSummary$StrengthSpMaleQualCorr<-DegreeOfCorr
                  PopSummary$WPsWeighting<-WPsEff
                  PopSummary$EpisodeRelation<-Integration
                  
                  
                  PopSummaryTot<-rbind(PopSummaryTot, PopSummary)
                  
                  
                }
                #now add information on the  species and population
                GradientSummary$population<-PopID
                GradientSummary$species<-Species
                
                VarianceTerms$population<-PopID
                VarianceTerms$species<-Species
                
                #more fully summarize the extra-pair paternity patterns
                PopSummaryTot2<-PopSummaryTot%>%
                  group_by(Clutch, NEPKidsFem, SimID, Geography,  FemPower, FemCrypticPower, ConstraintDist, 
                           DirectionSpMaleQualCorr,StrengthSpMaleQualCorr, WPsWeighting)%>%
                  summarise(NBroodsWithXEPKidsb=sum(NBroodsWithXEPKids))%>%
                  ungroup()
                PopSummaryTot2$population<-PopID
                PopSummaryTot2$species<-Species
                
                PairedTot1$population<-PopID
                PairedTot1$species<-Species
                
                EPsireDescrSummary$population<-PopID
                EPsireDescrSummary$species<-Species
                
                
                #add the condition-set results to the total results acrosss all conditions
                GrandVarianceTerms<-rbind(GrandVarianceTerms, VarianceTerms)
                GrandGradientSummary<-rbind(GrandGradientSummary, GradientSummary)
                GrandPopSummaryTot<-rbind(GrandPopSummaryTot, PopSummaryTot2)
                GrandEPsireDescrSummary<-rbind(GrandEPsireDescrSummary, EPsireDescrSummary)
                GrandPaired<-rbind(GrandPaired, PairedTot1)
                
              }}}}}}}}}




#save the data files after each species is complete
write.table(GrandVarianceTerms, file = "Variance.csv", sep = ",", row.names = F)
write.table(GrandGradientSummary, file = "Gradients.csv", sep = ",", row.names = F)
write.table(GrandPopSummaryTot, file = "PopSummary.csv", sep = ",", row.names = F)
write.table(GrandEPsireDescrSummary, file = "EPSireDescriptions.csv", sep = ",", row.names = F)
write.table(GrandPaired, file = "Ttests.csv", sep = ",", row.names = F)